@@ -1,15 +1,10 @@
 import torch
 from PIL import Image
-from matplotlib import pyplot as plt
-
-from diamond.image_caption.utils import load_images_from_numpy
-from diamond.user_classes import ImagesData, ImageDescriptionSpec
-import numpy as np
-import os
-from transformers import VisionEncoderDecoderModel, ViTImageProcessor, AutoTokenizer
-from transformers import pipeline
-import timm
 from PIL import ImageDraw
+from matplotlib import pyplot as plt
+from transformers import pipeline
+
+from diamond.user_classes import ImagesData
 
 
 class ImageObjectDetection:
@@ -34,8 +29,12 @@ class ImageObjectDetection:
     def detect_objects(self):
         bounding_boxes = []
         for image in self.images:
-            bounding_box = self.model(image)
-            bounding_boxes.append(bounding_box)
+            # Run object detection on image
+            detections = self.model(image)
+
+            # Append detections to list
+            bounding_boxes.append(detections)
+
         return bounding_boxes
 
     def plot_detected_objets(self):
