@@ -15,14 +15,14 @@ with open("/Users/amitosi/PycharmProjects/chester/chester/data/data_batch_1", 'r
 
 # convert the images and labels arrays to numpy arrays
 # Extract the images and labels
-images = data[b'data'][0:20]
-labels = np.array(data[b'labels'][0:20])
+images = data[b'data'][0:100]
+labels = np.array(data[b'labels'][0:100])
 
 # images = np.array(images[0:50])
 # labels = np.array(labels[0:50])
 
 
-image_shape = (3, 64, 64)
+image_shape = (3, 32, 32)
 
 image_model_list = [
     ImageModel(network_name="EfficientNetB0",
@@ -36,9 +36,10 @@ diamond_collector = run(images=images,
                         image_shape=image_shape,
                         labels=labels,
                         get_image_description=False,
-                        get_object_detection=True,
-                        is_augment_data=False,
+                        get_object_detection=False,
+                        detect_faces=False,
+                        is_augment_data=True,
                         image_augmentation_info=ImagesAugmentationInfo(aug_prop=0.1),
-                        is_train_model=False, image_models=image_models,
-                        is_post_model_analysis=False,
-                        plot=False)
+                        is_train_model=True, image_models=image_models,
+                        is_post_model_analysis=True,
+                        plot=True)
