@@ -30,7 +30,10 @@ class VideoReverser:
 
         video.release()
         if play:
-            self.play_reversed_video()
+            try:
+                self.play_reversed_video()
+            except:
+                print("Cannot play video on collab, you can read the video and use the vis module to plot images")
         return video
 
     def play_reversed_video(self):
